import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/suchitra2602/a0cea88423d0f41a170147bf7e2fba8f/raw/0ae34e19d15e49fed8c0d3427215da6e6c559c52/ICE6.csv'
const width = 920;
const height = 420;
const margin = { top: 12, right: 50, bottom: 0, left: 150 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.count = +d['Revenue(In Billion Dollars)'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0,700));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 30;
  const innerWidth = width - margin.left - margin.right + 10;
 
  const yScale = scaleBand()
    .domain(data.map(d => d.Name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.count)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 1}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Name}
            x={0}
            y={yScale(d.Name)}
            width={xScale(d.count)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};      
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);